@@ -1,11 +1,12 @@
 context("test-ggsurvtable")
 
-library(dplyr)
-library("survival")
-data("lung")
-fit <- survfit(Surv(time, status) ~ sex, data = lung)
+
 
 test_that("survtable y axis label colors work", {
+  library(dplyr)
+  library("survival")
+  #data("lung", package = "survival")
+  fit <- survfit(Surv(time, status) ~ sex, data = lung)
   p <- ggrisktable(fit, data = lung, color = "strata")
   .build <- ggplot_build(p)
   .build_data <- .build$data[[1]]
